/*******************************************************************************
 * Copyright (C) 2006 Ping Identity Corporation All rights reserved.
 * 
 * This software is licensed under the Open Software License v2.1 (OSL v2.1).
 * 
 * A copy of this license has been provided with the distribution of this
 * software. Additionally, a copy of this license is available at:
 * http://opensource.org/licenses/osl-2.1.php
 *  
 ******************************************************************************/
using System;
using System.Collections;
using System.Configuration;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using Com.PingIdentity.PingFederate.SampleApp.SampleAppUtility;

namespace Com.PingIdentity.PingFederate.SampleApp.SpSample.web {
	/// <summary>
	/// Summary description for accountLinking.
	/// </summary>
	public class AccountLinking : Page {

		protected HtmlInputHidden ResumePath;
		protected DropDownList    userName;
		protected HtmlInputText   Password;
		protected HtmlInputButton Submit;
		protected Label           ErrorLabel;

		private String loginType;
		protected System.Web.UI.HtmlControls.HtmlForm LinkingForm;
		private Links  samlLinks;
	
		private void Page_Load(object sender, EventArgs e) {

			//get loginType parameter: global or local
			loginType = Request.QueryString.Get(Constants.LOGIN_TYPE);
			if(loginType == null) {
				loginType = Constants.LOCAL_TYPE;
			}

			//get properties from Sp config file
			Hashtable spConfigTable;
			if(Session[Constants.SP_CONFIG_TABLE] == null) {
				spConfigTable = GetSpConfigProps(this.Context);
				Session[Constants.SP_CONFIG_TABLE] = spConfigTable;
			}
			else {
				spConfigTable = (Hashtable)Session[Constants.SP_CONFIG_TABLE];
			}

			samlLinks = new Links(spConfigTable, Request);

			//get resumePath and save it in hidden field
			String resumePath = Request.QueryString.Get(Constants.RESUME_PATH);
			if(resumePath != null) {
				this.ResumePath.Value = resumePath;
			}

			if(!IsPostBack) 
			{	
				PopulateUserNameList(this.Context);
				if(Request["error"] != null)
				{
					ErrorLabel.Text = Request["error"];
				}
			}
			else
			{
				Authenticate();
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Submit.ServerClick += new System.EventHandler(this.Submit_ServerClick);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void Submit_ServerClick(object sender, System.EventArgs e) {
			Authenticate();

		}

		private Hashtable GetSpConfigProps(HttpContext context) {

			//read properties from Sp config XML file
			String spConfig  = ConfigurationSettings.AppSettings["config-file"];
			String configPath = context.Server.MapPath("config/" + spConfig);

			XmlUtility xmlUtility = new XmlUtility();
			Hashtable spConfigTable = xmlUtility.GetConfigProps(configPath);
			if(spConfigTable == null) {
				String errorMessage = "Error in " + spConfig;
				context.Response.Redirect(Constants.WEB_PREFIX + Constants.ERROR_PAGE + errorMessage);
			}
			return spConfigTable;
		}

		private void PopulateUserNameList(HttpContext context) 	
		{
			//read properties from Idp users XML file
			String idpUsers  = ConfigurationSettings.AppSettings["users-props-file"];
			String usersPath = context.Server.MapPath("config/" + idpUsers);

			XmlUtility xmlUtility = new XmlUtility();
			ArrayList usersList = xmlUtility.GetPropsFromXmlFile(usersPath);
			if(usersList == null || usersList.Count == 0) 
			{
				String errorMessage = "Error in " + usersList;
				context.Response.Redirect(Constants.WEB_PREFIX + Constants.ERROR_PAGE + errorMessage);
			}
			else
			{
				for(int i = 0; i < usersList.Count; i++) 
				{
					Hashtable user  = (Hashtable)usersList[i];
					String userId = (String)user[Constants.USER_ID];
					userName.Items.Add(userId);
					
				}
			}
		}

		private void Authenticate()
		{
			String spUsers = ConfigurationSettings.AppSettings["users-props-file"];
			String usersPath = Server.MapPath("config/" + spUsers);

			XmlUtility xmlUtility = new XmlUtility();
			Hashtable userInfo = xmlUtility.AuthenticateUser(userName.SelectedValue,
				Password.Value, usersPath);
			if(userInfo != null) 
			{
				userInfo.Remove(Constants.USER_PASSWORD);
				Session[Constants.USER_INFO] = userInfo;
				if(loginType.Equals(Constants.LOCAL_TYPE)) 
				{
					String urlToSpHome = samlLinks.getSpHomeUrl();
					String resumePath = this.ResumePath.Value;
					if(resumePath != null) 
					{
						urlToSpHome = samlLinks.addParameter(urlToSpHome,
							Constants.RESUME_PATH, resumePath);
					}
					Response.Redirect(urlToSpHome);                  //redirect to MainHandler
				}
				else if(loginType.Equals(Constants.GLOBAL_TYPE)) 
				{
					String urlToAccountLinkingSpHandler = samlLinks.getAccountLinkingSpHandlerUrl();
					String resumePath = this.ResumePath.Value;
					if(resumePath != null) 
					{
						urlToAccountLinkingSpHandler = samlLinks.addParameter(
							urlToAccountLinkingSpHandler, Constants.RESUME_PATH, resumePath);
					}
					Response.Redirect(urlToAccountLinkingSpHandler); //redirect to AccountLinkingHandler
				}
				else 
				{
					String errorPage = samlLinks.getSpErrorPageUrl();
					String errorMessage = "Invalid loginType parameter!";
					Response.Redirect(errorPage + errorMessage);
				}
			}
			else 
			{
				ErrorLabel.Text = "Invalid Credentials: Please try again";
			}
		}

	}
}