<%
/*******************************************************************************
* Copyright (C) 2006 Ping Identity Corporation All rights reserved.
*
* This software is licensed under the Open Software License v2.1 (OSL v2.1).
*
* A copy of this license has been provided with the distribution of this
* software. Additionally, a copy of this license is available at:
* http://opensource.org/licenses/osl-2.1.php
*
******************************************************************************
*/
%>
<%@ page language="java" contentType="text/html; charset=ISO-8859-1"
    pageEncoding="ISO-8859-1"%>
<%@ page import = "com.pingidentity.adapters.pftoken.core.PFTokenException" %>
<%@ page import = "com.pingidentity.adapters.pftoken.core.PFTokenAgent" %>
<%@ page import = "com.pingidentity.adapters.pftoken.util.PFTokenConstants" %>

<%!

	/**
	 * setPFToken method uses the Java Integration Kit API to create an
	 * instance of Idp Agent. The user attributes are added to this agent and
	 * then the PFTOKEN is created.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 * @param url
	 * 				url to append PFTOKEN
  	 * @param userInfo
	 * 				user attributes
	 */
	private String setPFToken(HttpServletRequest request,
			HttpServletResponse response, String url, Map userInfo)
			throws IOException, ServletException {
		String returnUrl = url;

		Properties configProperties= getProperties(configFilePath);

		// Get password for encryption
		String password = configProperties.getProperty("password");

		// Get PFTOKEN Holder name
		String holderName = configProperties.getProperty("holderName");

		// Create PFTOKEN Idp Agent
		PFTokenAgent idpAgent = new PFTokenAgent(password,holderName);

		// Add user attributes to the agent
		idpAgent.addAttributes(userInfo);
		try {
			// Create PFTOKEN cookie
			returnUrl = idpAgent.constructPFToken(request, response, url);
		}
		catch(PFTokenException e) {
			throw new ServletException(e);
		}
		return returnUrl;
	}


     /**
	* setLogoutPFToken method uses the Java Integration Kit API to create an
	* instance of Idp Agent. The user attributes are added to this agent and
	* then the PFTOKEN logout token is created as a cookie or query parameter
	* @param request
	* 				current user request
	* @param response
	* 				current user response
	* @param url
	* 				url to append PFTOKEN
	* @param userInfo
	* 				Map of user attributes
	* @param logoutSuccessful
	* 				flag indicating successful logout
	*/
	private String setLogoutPFToken(HttpServletRequest request,
			HttpServletResponse response, String url, Map userInfo, boolean logoutSuccessful)
			throws IOException, ServletException {

		String returnUrl = url;

		Properties configProperties= getProperties(configFilePath);

		// Get password for encryption
		String password = configProperties.getProperty("password");

		// Get PFTOKEN Holder name
		String holderName = configProperties.getProperty("holderName");

		// Create PFTOKEN Idp Agent
		PFTokenAgent idpAgent = new PFTokenAgent(password,holderName);

		// Add user attributes to the agent
		idpAgent.addAttributes(userInfo);
		try {
			// Create PFTOKEN logout cookie
			returnUrl = idpAgent.constructLogoutPFToken(request, response, url, logoutSuccessful);
		}
		catch(PFTokenException e) {
			throw new ServletException(e);
		}
		return returnUrl;
	}


	/**
	 * forceAuthentication method retrieves the ForceAuthn parameter from
	 * request and returns the value in boolean.
	 * @param request
	 * 				current user request
	 * @return boolean
	 * 				flag to indicate if login is required
	 */
	private boolean forceAuthentication(HttpServletRequest request) {

		// Retrieve parameters from request
		String forceAuthn   = request.getParameter(PFTokenConstants.FORCE_AUTH_PARAMETER);

		boolean forceFlag   = false;

		// Convert string parameters to boolean
		if(forceAuthn != null && forceAuthn.equalsIgnoreCase(
				PFTokenConstants.TRUE_STRING_VALUE )) {
			forceFlag = true;
		}
		return forceFlag;
	}

	/**
	 * isPassive method retrieves the ForceAuthn parameter from
	 * request and returns the value in boolean.
	 * @param request
	 * 				current user request
	 * @return boolean
	 * 				flag to indicate if login is required
	 */
	private boolean isPassive(HttpServletRequest request) {

		// Retrieve parameters from request
		String isPassive   = request.getParameter(PFTokenConstants.IS_PASSIVE_PARAMETER);

		boolean isPassiveFlag   = false;

		// Convert string parameters to boolean
		if(isPassive!= null && isPassive.equalsIgnoreCase(
				PFTokenConstants.TRUE_STRING_VALUE )) {
			isPassiveFlag = true;
		}
		return isPassiveFlag;
	}



%>